==> refcodes-io-1.10.2-sources.jar: org/refcodes/io/InputStreamConnectionReceiverImpl.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.io;

import java.io.InputStream;
import java.io.Serializable;

import org.refcodes.component.OpenException;

/**
 * Implementation of the {@link InputStreamConnectionReceiver} interface.
 *
 * @param <DATA> The type of the datagram to be operated with.
 */
public class InputStreamConnectionReceiverImpl<DATA extends Serializable> extends AbstractInputStreamReceiver<DATA> implements InputStreamConnectionReceiver<DATA> {

	// /////////////////////////////////////////////////////////////////////////
	// CONSTANTS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// VARIABLES:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new input stream connection receiver impl.
	 */
	public InputStreamConnectionReceiverImpl() {
		super();
	}

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * {@inheritDoc}
	 */
	@Override
	public synchronized void open( InputStream aInputStream ) throws OpenException {
		super.open( aInputStream );
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean isOpenable( InputStream aInputStream ) {
		return super.isOpenable( aInputStream );
	}

	// /////////////////////////////////////////////////////////////////////////
	// HOOKS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HELPER:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// INNER CLASSES:
	// /////////////////////////////////////////////////////////////////////////
}

==> refcodes-io-3.2.9-sources.jar: org/refcodes/io/InputStreamConnectionReceiverImpl.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.io;

import java.io.IOException;
import java.io.InputStream;
import java.io.Serializable;

/**
 * Implementation of the {@link InputStreamConnectionReceiver} interface.
 *
 * @param <DATA> The type of the datagram to be operated with.
 */
public class InputStreamConnectionReceiverImpl<DATA extends Serializable> extends AbstractInputStreamReceiver<DATA> implements InputStreamConnectionReceiver<DATA> {

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new input stream connection receiver impl.
	 */
	public InputStreamConnectionReceiverImpl() {}

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * {@inheritDoc}
	 */
	@Override
	public synchronized void open( InputStream aInputStream ) throws IOException {
		super.open( aInputStream );
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean isOpenable( InputStream aInputStream ) {
		return super.isOpenable( aInputStream );
	}
}
